==> matex_dart-0.9.5.tar.gz: lib/core/models/dividend_reinvestment_payout_yearly_report.model.dart <==
import 'package:matex_dart/matex_dart.dart';

class MatexDividendReinvestementYearlyPayoutReport
    extends MatexDividendReinvestementPayoutReport {
  final List<MatexDividendReinvestementPayoutReport> payouts;
  final double dividendAmountPerShare;
  final double cumulativeContribution;

  MatexDividendReinvestementYearlyPayoutReport({
    this.payouts = const <MatexDividendReinvestementPayoutReport>[],
    double additionalSharesFromAnnualContribution = 0,
    double additionalSharesFromDrip = 0,
    double cumulativeGrossAmount = 0,
    this.dividendAmountPerShare = 0,
    this.cumulativeContribution = 0,
    double cumulativeNetAmount = 0,
    double grossDividendPayout = 0,
    double netDividendPayout = 0,
    double averageSharePrice = 0,
    double numberOfShares = 0,
    double endingBalance = 0,
    double sharePrice = 0,
  }) : super(
          additionalSharesFromAnnualContribution:
              additionalSharesFromAnnualContribution,
          additionalSharesFromDrip: additionalSharesFromDrip,
          cumulativeGrossAmount: cumulativeGrossAmount,
          cumulativeNetAmount: cumulativeNetAmount,
          grossDividendPayout: grossDividendPayout,
          netDividendPayout: netDividendPayout,
          averageSharePrice: averageSharePrice,
          numberOfShares: numberOfShares,
          endingBalance: endingBalance,
          sharePrice: sharePrice,
        );

  @override
  List<dynamic> get props => [
        additionalSharesFromAnnualContribution,
        additionalSharesFromDrip,
        dividendAmountPerShare,
        cumulativeContribution,
        cumulativeGrossAmount,
        cumulativeNetAmount,
        grossDividendPayout,
        averageSharePrice,
        netDividendPayout,
        numberOfShares,
        endingBalance,
        sharePrice,
        payouts,
      ];
}

==> matex_dart-0.11.1.tar.gz: lib/core/models/dividend_reinvestment_payout_yearly_report.model.dart <==
import 'package:matex_dart/matex_dart.dart';

class MatexDividendReinvestementYearlyPayoutReport
    extends MatexDividendReinvestementPayoutReport {
  final List<MatexDividendReinvestementPayoutReport> payouts;
  final double dividendAmountPerShare;
  final double cumulativeContribution;

  const MatexDividendReinvestementYearlyPayoutReport({
    this.payouts = const <MatexDividendReinvestementPayoutReport>[],
    double additionalSharesFromAnnualContribution = 0,
    double additionalSharesFromDrip = 0,
    double cumulativeGrossAmount = 0,
    this.dividendAmountPerShare = 0,
    this.cumulativeContribution = 0,
    double cumulativeNetAmount = 0,
    double grossDividendPayout = 0,
    double netDividendPayout = 0,
    double averageSharePrice = 0,
    double numberOfShares = 0,
    double endingBalance = 0,
    double sharePrice = 0,
  }) : super(
          additionalSharesFromAnnualContribution:
              additionalSharesFromAnnualContribution,
          additionalSharesFromDrip: additionalSharesFromDrip,
          cumulativeGrossAmount: cumulativeGrossAmount,
          cumulativeNetAmount: cumulativeNetAmount,
          grossDividendPayout: grossDividendPayout,
          netDividendPayout: netDividendPayout,
          averageSharePrice: averageSharePrice,
          numberOfShares: numberOfShares,
          endingBalance: endingBalance,
          sharePrice: sharePrice,
        );

  @override
  List<dynamic> get props => [
        additionalSharesFromAnnualContribution,
        additionalSharesFromDrip,
        dividendAmountPerShare,
        cumulativeContribution,
        cumulativeGrossAmount,
        cumulativeNetAmount,
        grossDividendPayout,
        averageSharePrice,
        netDividendPayout,
        numberOfShares,
        endingBalance,
        sharePrice,
        payouts,
      ];
}
